@@ -94,6 +94,30 @@ public class MainClassApplicationTypeFactory extends AbstractModelProvider<Appli
         
         // Java DB
         {"org.apache.derby.drda.NetworkServerControl", "JavaDB", descr("DESCR_JavaDb"), "com/sun/tools/visualvm/application/type/resources/JavaDB.png"},   // NOI18N
+
+        // JRockit Mission Control
+        {"com.jrockit.mc.rcp.start.MCMain","JRockit Mission Control",descr("DESCR_JRMC"),"com/sun/tools/visualvm/application/type/resources/JRMC.png"},  // NOI18N
+
+        // Oracle WebLogic
+        {"weblogic.Server","WebLogic",descr("DESCR_WLS"),"com/sun/tools/visualvm/application/type/resources/WLS.png"},  // NOI18N
+        
+        // JRuby runtime
+        {"org.jruby.Main",descr("LBL_Jruby"),descr("DESCR_Jruby"),"com/sun/tools/visualvm/application/type/resources/JRuby.png"},  // NOI18N
+        
+        // Scala runtime
+        {"scala.tools.nsc.MainGenericRunner",descr("LBL_Scala"),descr("DESCR_Scala"),"com/sun/tools/visualvm/application/type/resources/Scala.png"},  // NOI18N
+        
+        // Clojure runtime
+        {"clojure.main",descr("LBL_Clojure"),descr("DESCR_Clojure"),"com/sun/tools/visualvm/application/type/resources/Clojure.png"},  // NOI18N
+        {"clojure.jar",descr("LBL_Clojure"),descr("DESCR_Clojure"),"com/sun/tools/visualvm/application/type/resources/Clojure.png"},  // NOI18N
+        {"clojure.lang.Script",descr("LBL_Clojure"),descr("DESCR_Clojure"),"com/sun/tools/visualvm/application/type/resources/Clojure.png"},  // NOI18N
+        {"clojure.lang.Repl",descr("LBL_Clojure"),descr("DESCR_Clojure"),"com/sun/tools/visualvm/application/type/resources/Clojure.png"},  // NOI18N
+        
+        // Groovy runtime
+        {"org.codehaus.groovy.tools.GroovyStarter",descr("LBL_Groovy"),descr("DESCR_Groovy"),"com/sun/tools/visualvm/application/type/resources/Groovy.png"},  // NOI18N
+        
+        // Jython runtime
+        {"org.python.util.jython",descr("LBL_Jython"),descr("DESCR_Jython"),"com/sun/tools/visualvm/application/type/resources/Jython.png"},  // NOI18N
     };
     
     Map<String,String[]> map;
