@@ -36,6 +36,7 @@ import com.sun.tools.visualvm.core.ui.DataSourceView;
 import com.sun.tools.visualvm.core.ui.components.DataViewComponent;
 import com.sun.tools.visualvm.core.ui.components.NotSupportedDisplayer;
 import com.sun.tools.visualvm.heapdump.HeapDumpSupport;
+import com.sun.tools.visualvm.uisupport.HTMLTextArea;
 import java.awt.BorderLayout;
 import java.awt.Toolkit;
 import java.awt.event.ActionEvent;
@@ -50,7 +51,6 @@ import javax.swing.JPanel;
 import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
-import org.netbeans.lib.profiler.ui.components.HTMLTextArea;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
@@ -201,8 +201,13 @@ class ApplicationMonitorView extends DataSourceView {
             
             heapDumpButton = new JButton(new AbstractAction(NbBundle.getMessage(ApplicationMonitorView.class, "LBL_Heap_Dump")) {   // NOI18N
                 public void actionPerformed(ActionEvent e) {
-                    HeapDumpSupport.getInstance().takeHeapDump((Application)model.getSource(), (e.getModifiers() &
-                            Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()) == 0);
+                    Application application = (Application)model.getSource();
+                    boolean local = application.isLocalApplication();
+                    boolean tagged = (e.getModifiers() & Toolkit.getDefaultToolkit().
+                                      getMenuShortcutKeyMask()) != 0;
+                    HeapDumpSupport hds = HeapDumpSupport.getInstance();
+                    if (local) hds.takeHeapDump(application, !tagged);
+                    else hds.takeRemoteHeapDump(application, null, !tagged);
                 }
             });
             heapDumpButton.setEnabled(model.isTakeHeapDumpSupported());
