@@ -41,6 +41,7 @@ import com.sun.tools.visualvm.tools.jmx.JmxModelFactory;
 import com.sun.tools.visualvm.tools.jmx.JvmMXBeans;
 import com.sun.tools.visualvm.tools.jmx.JvmMXBeansFactory;
 import com.sun.tools.visualvm.tools.jmx.MBeanCacheListener;
+import com.sun.tools.visualvm.uisupport.HTMLTextArea;
 import java.awt.BorderLayout;
 import java.awt.Toolkit;
 import java.awt.event.ActionEvent;
@@ -53,13 +54,12 @@ import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.JPanel;
 import javax.swing.SwingUtilities;
-import org.netbeans.lib.profiler.ui.components.HTMLTextArea;
 import org.netbeans.lib.profiler.ui.threads.ThreadsDetailsPanel;
 import org.netbeans.lib.profiler.ui.threads.ThreadsPanel;
 import org.netbeans.lib.profiler.ui.threads.ThreadsTablePanel;
-import org.netbeans.modules.profiler.ui.NBSwingWorker;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
+import org.openide.util.RequestProcessor;
 import org.openide.util.WeakListeners;
 
 /**
@@ -170,6 +170,8 @@ class ApplicationThreadsView extends DataSourceView implements DataRemovedListen
 
     private static class MasterViewSupport extends JPanel implements DataRemovedListener<Application>, PropertyChangeListener {
 
+        private static RequestProcessor worker = null;
+
         private Application application;
         private HTMLTextArea area;
         private JButton threadDumpButton;
@@ -237,8 +239,8 @@ class ApplicationThreadsView extends DataSourceView implements DataRemovedListen
 
             final int[] threads = new int[2];
 
-            new NBSwingWorker() {
-                protected void doInBackground() {
+            getWorker().post(new Runnable() {
+                public void run() {
                     try {
                         threads[0] = threadsManager.getThreadCount();
                         threads[1] = threadsManager.getDaemonThreadCount();
@@ -246,12 +248,13 @@ class ApplicationThreadsView extends DataSourceView implements DataRemovedListen
                         threads[0] = 0;
                         threads[1] = 0;
                     }
+                    SwingUtilities.invokeLater(new Runnable() {
+                        public void run() {
+                            updateThreadsCounts(threads[0], threads[1]);
+                        }
+                    });
                 }
-                @Override
-                protected void done() {
-                    updateThreadsCounts(threads[0], threads[1]);
-                }
-            }.execute();
+            });
         }
 
         private void updateThreadsCounts(int liveThreads, int daemonThreads) {
@@ -265,6 +268,12 @@ class ApplicationThreadsView extends DataSourceView implements DataRemovedListen
             area.setText(data.toString());
             area.select(selStart, selEnd);
         }
+
+        private static synchronized RequestProcessor getWorker() {
+            if (worker == null) worker = new RequestProcessor("ThreadsWorker", 1); // NOI18N
+            return worker;
+        }
+
     }
 
     // --- Timeline ------------------------------------------------------------
