@@ -26,11 +26,13 @@
 package com.sun.tools.visualvm.core.datasource.descriptor;
 
 import com.sun.tools.visualvm.core.datasource.DataSource;
+import com.sun.tools.visualvm.core.datasource.Storage;
 import com.sun.tools.visualvm.core.datasupport.Positionable;
 import com.sun.tools.visualvm.core.model.Model;
 import java.awt.Image;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
+import java.util.Comparator;
 
 /**
  * DataSourceDescriptor defines runtime appearance of the DataSource in Applications window.
@@ -56,6 +58,10 @@ public abstract class DataSourceDescriptor<X extends DataSource> extends Model i
      * Named property for DataSource position within its owner.
      */
     public static final String PROPERTY_PREFERRED_POSITION = "prop_preferred_position"; // NOI18N
+    /**
+     * Named property for comparator used to sort nested DataSources.
+     */
+    public static final String PROPERTY_CHILDREN_COMPARATOR = "prop_children_comparator"; // NOI18N
     /**
      * Named property for DataSource expansion policy.
      */
@@ -86,6 +92,7 @@ public abstract class DataSourceDescriptor<X extends DataSource> extends Model i
     private String name;
     private String description;
     private int preferredPosition;
+    private Comparator<DataSource> childrenComparator;
     private int autoExpansionPolicy;
     private final PropertyChangeSupport changeSupport;
     
@@ -182,6 +189,19 @@ public abstract class DataSourceDescriptor<X extends DataSource> extends Model i
     public int getPreferredPosition() {
         return preferredPosition;
     }
+
+    /**
+     * Returns comparator used to sort nested DataSources. If defined, it overrides
+     * the default sorting which uses DataSourceDescriptor.getPreferredPosition().
+     * Default implementation returns null.
+     *
+     * @return comparator used to sort nested DataSources or null
+     *
+     * @since VisualVM 1.3
+     */
+    public Comparator<DataSource> getChildrenComparator() {
+        return childrenComparator;
+    }
     
     /**
      * Returns expansion policy of the DataSource.
@@ -198,6 +218,8 @@ public abstract class DataSourceDescriptor<X extends DataSource> extends Model i
      *
      * @return true if the General properties section should be available for
      * the DataSource, false otherwise
+     *
+     * @since VisualVM 1.2
      */
     public boolean providesProperties() {
         return false;
@@ -290,6 +312,20 @@ public abstract class DataSourceDescriptor<X extends DataSource> extends Model i
         preferredPosition = newPosition;
         getChangeSupport().firePropertyChange(PROPERTY_PREFERRED_POSITION, oldPosition, newPosition);
     }
+
+    /**
+     * Sets a custom comparator for sorting DataSources within a DataSource.
+     * Use setChildrenComparator(null) to restore the default sorting.
+     *
+     * @param newComparator comparator for sorting DataSources within a DataSource
+     *
+     * @since VisualVM 1.3
+     */
+    protected void setChildrenComparator(Comparator<DataSource> newComparator) {
+        Comparator<DataSource> oldComparator = childrenComparator;
+        childrenComparator = newComparator;
+        getChangeSupport().firePropertyChange(PROPERTY_CHILDREN_COMPARATOR, oldComparator, newComparator);
+    }
     
     protected void getAutoExpansionPolicy(int newPolicy) {
         int oldPolicy = autoExpansionPolicy;
@@ -301,4 +337,51 @@ public abstract class DataSourceDescriptor<X extends DataSource> extends Model i
         return changeSupport;
     }
 
+
+    /**
+     * Returns persisted DataSource name if available in DataSource Storage as
+     * PROPERTY_NAME. Otherwise returns the provided name.
+     *
+     * @param dataSource DataSource for which to resolve the name
+     * @param name name to be used if not available in DataSource Storage
+     * @return persisted DataSource name if available or the provided name
+     *
+     * @since VisualVM 1.3
+     */
+    protected static String resolveName(DataSource dataSource, String name) {
+        String persistedName = dataSource.getStorage().getCustomProperty(PROPERTY_NAME);
+        if (persistedName != null) return persistedName;
+        else return name;
+    }
+
+    /**
+     * Returns persisted DataSource position if available in DataSource Storage
+     * as PROPERTY_PREFERRED_POSITION. Otherwise uses the provided position.
+     * Optionally saves the position to DataSource storage which also ensures that
+     * relative positions POSITION_AT_THE_END and POSITION_LAST will be correctly
+     * persisted.
+     *
+     * @param dataSource DataSource for which to resolve the position
+     * @param position position to be used if not available in DataSource Storage
+     * @param savePosition true when the position should be saved to DataSource's Storage
+     * @return persisted DataSource position if available or the provided position
+     *
+     * @since VisualVM 1.3
+     */
+    protected static int resolvePosition(DataSource dataSource, int position,
+                                         boolean savePosition) {
+        Storage storage = dataSource.getStorage();
+        String positionS = storage.getCustomProperty(PROPERTY_PREFERRED_POSITION);
+        if (positionS != null) try {
+                position = Integer.parseInt(positionS);
+            } catch (NumberFormatException e) {
+                if (savePosition) storage.setCustomProperty(PROPERTY_PREFERRED_POSITION,
+                                                            Integer.toString(position));
+        } else {
+            if (savePosition) storage.setCustomProperty(PROPERTY_PREFERRED_POSITION,
+                                                        Integer.toString(position));
+        }
+        return position;
+    }
+
 }
