@@ -37,6 +37,7 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -45,6 +46,7 @@ import java.util.Set;
 import javax.swing.ImageIcon;
 import javax.swing.SwingUtilities;
 import javax.swing.tree.DefaultTreeModel;
+import javax.swing.tree.TreeNode;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
 import org.openide.util.NbBundle;
@@ -63,10 +65,13 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
     private final ExplorerNode explorerRoot;
     private final DefaultTreeModel explorerModel;
     
-    private final Map<DataSource, ExplorerNode> nodes;
+    private final Map<DataSource, ExplorerNode> nodes = new HashMap();
     private final Map<DataSource, PropertyChangeListener> visibilityListeners = new HashMap();
     private final Map<DataSourceDescriptor, PropertyChangeListener> descriptorListeners = new HashMap();
-    
+
+    private static final ExplorerNodesComparator RELATIVE_COMPARATOR =
+            new ExplorerNodesComparator(new RelativePositionComparator());
+
     
     public static synchronized ExplorerModelBuilder getInstance() {
         if (instance == null) instance = new ExplorerModelBuilder();
@@ -81,8 +86,8 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
     ExplorerNode getNodeFor(DataSource dataSource) {
         return nodes.get(dataSource);
     }
-    
-    
+
+        
     public void dataChanged(final DataChangeEvent event) {
         queue.post(new Runnable() {
             public void run() {
@@ -126,9 +131,9 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
     }
     
     private void processAddedDisplayableDataSources(Set<DataSource> addedDisplayable) {
-        final Set<ExplorerNode> addedNodes = new HashSet();
+        final List<ExplorerNode> addedNodes = new ArrayList();
         final ProgressHandle[] pHandle = new ProgressHandle[1];
-        
+
         SwingUtilities.invokeLater(new Runnable() {
 
             public void run() {
@@ -162,6 +167,9 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
                 public void run() { pHandle[0].finish(); }
             });
         }
+
+        Collections.sort(addedNodes, RELATIVE_COMPARATOR);
+
         try { SwingUtilities.invokeAndWait(new Runnable() {
             public void run() { addNodes(addedNodes); }
         }); } catch (Exception e) {}
@@ -199,6 +207,7 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
         node.setName(descriptor.getName());
         node.setIcon(descriptor.getIcon() == null ? null : new ImageIcon(descriptor.getIcon()));
         node.setPreferredPosition(descriptor.getPreferredPosition());
+        node.setComparator(descriptor.getChildrenComparator());
         node.setAutoExpansionPolicy(descriptor.getAutoExpansionPolicy());
     }
     
@@ -209,10 +218,13 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
         // Node name needs to be updated
         if (DataSourceDescriptor.PROPERTY_NAME.equals(property)) {
             String name = (String)newValue;
-            node.setName(name);
-            try { SwingUtilities.invokeAndWait(new Runnable() {
-                public void run() { explorerModel.nodeChanged(node); }
-            }); } catch (Exception e) {}
+            Runnable updater = node.setName(name) ?
+                new Runnable() {
+                    public void run() { updateContainer(node.getParent()); }
+                } : new Runnable() {
+                    public void run() { explorerModel.nodeChanged(node); }
+                };
+            try { SwingUtilities.invokeAndWait(updater); } catch (Exception e) {}
         // Node icon needs to be updated
         } else if (DataSourceDescriptor.PROPERTY_ICON.equals(property)) {
             Image icon = (Image)newValue;
@@ -236,12 +248,30 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
                     }
                 }); } catch (Exception e) {}
             }
+        } else if (DataSourceDescriptor.PROPERTY_CHILDREN_COMPARATOR.equals(property)) {
+            final Comparator<DataSource> comparator = (Comparator<DataSource>)newValue;
+            SwingUtilities.invokeLater(new Runnable() {
+                public void run() {
+                    if (node.setComparator(comparator)) updateContainer(node);
+                }
+            });
         } else if (DataSourceDescriptor.PROPERTY_EXPANSION_POLICY.equals(property)) {
             node.setAutoExpansionPolicy((Integer)evt.getNewValue());
         }
     }
+
+    private void updateContainer(TreeNode node) {
+        // Save selection
+        Set<DataSource> selectedDataSources = ExplorerSupport.sharedInstance().
+                                              getSelectedDataSources();
+
+        explorerModel.nodeStructureChanged(node);
+
+        // Try to restore selection
+        ExplorerSupport.sharedInstance().selectDataSources(selectedDataSources);
+    }
     
-    private void addNodes(Set<ExplorerNode> added) {
+    private void addNodes(List<ExplorerNode> added) {
         Map<ExplorerNode, List<Integer>> indexes = new HashMap();
         
         // Save selection
@@ -261,20 +291,22 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
             ExplorerNode nodeParent = (ExplorerNode)node.getParent();
             indexes.get(nodeParent).add(nodeParent.getIndex(node));
         }
-        
+
         // Notify tree model
+        // Synchronize relative positions
         for (Map.Entry<ExplorerNode, List<Integer>> entry : indexes.entrySet()) {
             List<Integer> indexesList = entry.getValue();
             Collections.sort(indexesList);
             int[] indexesArr = new int[indexesList.size()];
             for (int i = 0; i < indexesArr.length; i++) indexesArr[i] = indexesList.get(i);
-            explorerModel.nodesWereInserted(entry.getKey(), indexesArr);
+            final ExplorerNode parent = entry.getKey();
+            explorerModel.nodesWereInserted(parent, indexesArr);
         }
         
         // Try to restore selection
         ExplorerSupport.sharedInstance().selectDataSources(selectedDataSources);
     }
-    
+
     private void removeNodes(Set<ExplorerNode> removed) {
         Map<ExplorerNode, List<IndexNodePair>> pairs = new HashMap();
         
@@ -299,6 +331,7 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
         }
         
         // Notify tree model
+        // Synchronize relative positions
         for (Map.Entry<ExplorerNode, List<IndexNodePair>> entry : pairs.entrySet()) {
             List<IndexNodePair> indexesList = entry.getValue();
             Collections.sort(indexesList);
@@ -309,7 +342,8 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
                 indexesArr[i] = pair.index;
                 childsArr[i] = pair.node;
             }
-            explorerModel.nodesWereRemoved(entry.getKey(), indexesArr, childsArr);
+            final ExplorerNode parent = entry.getKey();
+            explorerModel.nodesWereRemoved(parent, indexesArr, childsArr);
         }
         
         // Try to restore selection
@@ -357,13 +391,27 @@ class ExplorerModelBuilder implements DataChangeListener<DataSource> {
         explorerRoot.setAutoExpansionPolicy(DataSourceDescriptor.EXPAND_ON_EACH_FIRST_CHILD);
         explorerModel = new DefaultTreeModel(explorerRoot);
         
-        nodes = new HashMap();
         nodes.put(DataSource.ROOT, explorerRoot);
         
         DataSourceRepository.sharedInstance().addDataChangeListener(this, DataSource.class);
     }
-    
-    
+
+
+    private static class RelativePositionComparator extends DataSourcesComparator {
+
+        protected int getRelativePosition(DataSource d, int positionType) {
+            try {
+                // throws NumberFormatException
+                return Integer.parseInt(d.getStorage().getCustomProperty(
+                                        ExplorerNode.PROPERTY_RELATIVE_POSITION));
+            } catch (Exception e) {
+                return positionType;
+            }
+        }
+
+    }
+
+
     private static class IndexNodePair implements Comparable {
         
         public int index;
