@@ -1,23 +1,23 @@
 /*
  * Copyright 2007-2008 Sun Microsystems, Inc.  All Rights Reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * This code is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 only, as
  * published by the Free Software Foundation.  Sun designates this
  * particular file as subject to the "Classpath" exception as provided
  * by Sun in the LICENSE file that accompanied this code.
- * 
+ *
  * This code is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * version 2 for more details (a copy is included in the LICENSE file that
  * accompanied this code).
- * 
+ *
  * You should have received a copy of the GNU General Public License version
  * 2 along with this work; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- * 
+ *
  * Please contact Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
  * CA 95054 USA or visit www.sun.com if you need additional information or
  * have any questions.
@@ -28,11 +28,14 @@ package com.sun.tools.visualvm.jvmstat.application;
 import com.sun.tools.visualvm.core.options.GlobalPreferences;
 import com.sun.tools.visualvm.core.properties.PropertiesPanel;
 import com.sun.tools.visualvm.core.ui.components.ScrollableContainer;
+import com.sun.tools.visualvm.core.ui.components.Spacer;
+import com.sun.tools.visualvm.uisupport.UISupport;
 import java.awt.CardLayout;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.Font;
+import java.awt.Graphics;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.Insets;
@@ -128,13 +131,14 @@ class ConnectionsCustomizer extends PropertiesPanel {
     private static Border selectedBorder() {
         Border b = UIManager.getBorder("Table.focusSelectedCellHighlightBorder"); // NOI18N
         if (b == null) b = UIManager.getBorder("Table.focusCellHighlightBorder"); // NOI18N
+        if (b != null) b = new SafeBorder(b); // #372, workarounds null from Border.getBorderInsets
         return b;
     }
 
-    private static Border emptyBorder(Border selectedBorder) {
-        Insets i = selectedBorder == null ? new Insets(0, 0, 0, 0) :
-                   selectedBorder.getBorderInsets(new JTextField());
-        return BorderFactory.createEmptyBorder(i.top, i.left, i.bottom, i.right);
+    private static Border emptyBorder(Border border) {
+        Insets i = border == null ? null : border.getBorderInsets(new JTextField());
+        return i == null ? BorderFactory.createEmptyBorder() :
+               BorderFactory.createEmptyBorder(i.top, i.left, i.bottom, i.right);
     }
 
 
@@ -215,7 +219,7 @@ class ConnectionsCustomizer extends PropertiesPanel {
         };
         table.setShowGrid(false);
         table.setIntercellSpacing(new Dimension());
-        table.setFillsViewportHeight(true);
+        table.setOpaque(false);
         table.getSelectionModel().addListSelectionListener(new ListSelectionListener() {
             public void valueChanged(ListSelectionEvent e) {
                 update();
@@ -237,19 +241,24 @@ class ConnectionsCustomizer extends PropertiesPanel {
         JScrollPane impl = new JScrollPane();
         JScrollPane scroll = new ScrollableContainer(table);
         scroll.setBorder(impl.getBorder());
-        scroll.setViewportBorder(impl.getViewportBorder());
+        if (!UISupport.isNimbusLookAndFeel())
+            scroll.setViewportBorder(impl.getViewportBorder());
+        scroll.getViewport().setOpaque(true);
+        scroll.getViewport().setBackground(UISupport.getDefaultBackground());
         scroll.setPreferredSize(new Dimension(TABLE_WIDTH + 20, 1));
 
         JLabel noConnection = new JLabel(NbBundle.getMessage(
                 ConnectionsCustomizer.class, "LBL_NoConnection"), JLabel.CENTER); // NOI18N
         noConnection.setEnabled(false);
-        noConnection.setOpaque(true);
-        noConnection.setBackground(table.getBackground());
+        noConnection.setOpaque(false);
         noConnection.setMinimumSize(new Dimension());
         JScrollPane emptyScroll = new JScrollPane(noConnection,
                 JScrollPane.VERTICAL_SCROLLBAR_NEVER, JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
-        emptyScroll.getViewport().setOpaque(false);
+        emptyScroll.getViewport().setOpaque(true);
+        emptyScroll.getViewport().setBackground(UISupport.getDefaultBackground());
         emptyScroll.setOpaque(false);
+        if (UISupport.isNimbusLookAndFeel())
+            emptyScroll.setViewportBorder(BorderFactory.createEmptyBorder());
         viewPanel = new JPanel(new CardLayout());
         viewPanel.setOpaque(false);
         viewPanel.add(emptyScroll, NO_DATA_VIEW);
@@ -319,19 +328,54 @@ class ConnectionsCustomizer extends PropertiesPanel {
     private JButton remove;
 
 
+    private static class SafeBorder implements Border {
+
+        private final Border impl;
+
+        SafeBorder(Border impl) { this.impl = impl; }
+
+        public void paintBorder(Component cmpnt, Graphics grphcs, int i, int i1, int i2, int i3) {
+            impl.paintBorder(cmpnt, grphcs, i, i1, i2, i3);
+        }
+
+        public Insets getBorderInsets(Component cmpnt) {
+            Insets insets = impl.getBorderInsets(cmpnt);
+            if (insets == null) insets = new Insets(0, 0, 0, 0);
+            return insets;
+        }
+
+        public boolean isBorderOpaque() {
+            return impl.isBorderOpaque();
+        }
+
+    }
+
+
     private static class CellRenderer extends JPanel implements TableCellRenderer {
 
         private static final int BORDER_HEIGHT = 4;
 
+        private static final Color BACKGROUND;
+        private static final Color DARKER_BACKGROUND;
+
+        static {
+            BACKGROUND = UISupport.getDefaultBackground();
+
+            int darkerR = BACKGROUND.getRed() - 11;
+            if (darkerR < 0) darkerR += 26;
+            int darkerG = BACKGROUND.getGreen() - 11;
+            if (darkerG < 0) darkerG += 26;
+            int darkerB = BACKGROUND.getBlue() - 11;
+            if (darkerB < 0) darkerB += 26;
+            DARKER_BACKGROUND = new Color(darkerR, darkerG, darkerB);
+        }
+
         private JLabel portLabel;
         private JLabel portValueLabel;
         private JLabel refreshLabel;
         private JLabel refreshValueLabel;
         private JLabel refreshUnitsLabel;
 
-        private Color color;
-        private Color darkerColor;
-
         private final NumberFormat format = NumberFormat.getInstance();
 
         public CellRenderer() {
@@ -403,8 +447,6 @@ class ConnectionsCustomizer extends PropertiesPanel {
             c.insets = new Insets(BORDER_HEIGHT, 5, BORDER_HEIGHT, 0);
             add(refreshUnitsLabel, c);
 
-            JPanel filler = new JPanel(null);
-            filler.setOpaque(false);
             c = new GridBagConstraints();
             c.gridx = 5;
             c.gridy = 0;
@@ -415,7 +457,7 @@ class ConnectionsCustomizer extends PropertiesPanel {
             c.fill = GridBagConstraints.BOTH;
             c.anchor = GridBagConstraints.NORTHWEST;
             c.insets = new Insets(0, 5, 0, 0);
-            add(filler, c);
+            add(Spacer.create(), c);
 
             setOpaque(true);
             setBorder(EMPTY_BORDER);
@@ -428,14 +470,9 @@ class ConnectionsCustomizer extends PropertiesPanel {
             portValueLabel.setText(format.format(cd.getPort()));
             refreshValueLabel.setText(format.format(cd.getRefreshRate()));
 
-            if (color == null) {
-                color = table.getBackground();
-                darkerColor = darker(color);
-            }
-
             if (!isSelected) {
                 boolean oddRow = row % 2 == 0;
-                setBackground(oddRow ? darkerColor : color);
+                setBackground(oddRow ? DARKER_BACKGROUND : BACKGROUND);
             }
 
             return this;
@@ -560,8 +597,6 @@ class ConnectionsCustomizer extends PropertiesPanel {
             c.insets = new Insets(BORDER_HEIGHT, 5, BORDER_HEIGHT, 5);
             add(refreshUnitsLabel, c);
 
-            JPanel filler = new JPanel(null);
-            filler.setOpaque(false);
             c = new GridBagConstraints();
             c.gridx = 5;
             c.gridy = 0;
@@ -572,7 +607,7 @@ class ConnectionsCustomizer extends PropertiesPanel {
             c.fill = GridBagConstraints.BOTH;
             c.anchor = GridBagConstraints.NORTHWEST;
             c.insets = new Insets(0, 5, 0, 0);
-            add(filler, c);
+            add(Spacer.create(), c);
 
             setOpaque(true);
             setBackground(BACKGROUND_COLOR);
