@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -40,24 +43,30 @@
 
 package org.netbeans.modules.profiler;
 
-import org.netbeans.lib.profiler.ProfilerLogger;
 import org.netbeans.lib.profiler.common.ProfilingSettings;
 import org.netbeans.lib.profiler.results.ResultsSnapshot;
 import org.netbeans.lib.profiler.results.coderegion.CodeRegionResultsSnapshot;
 import org.netbeans.lib.profiler.results.cpu.CPUResultsSnapshot;
+import org.netbeans.lib.profiler.results.cpu.CPUResultsSnapshot.NoDataAvailableException;
 import org.netbeans.lib.profiler.results.memory.AllocMemoryResultsSnapshot;
 import org.netbeans.lib.profiler.results.memory.LivenessMemoryResultsSnapshot;
 import org.openide.util.NbBundle;
 import java.io.*;
+import java.lang.management.ThreadInfo;
 import java.text.MessageFormat;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
 import java.util.Properties;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.zip.DataFormatException;
 import java.util.zip.Deflater;
+import java.util.zip.GZIPInputStream;
 import java.util.zip.Inflater;
+import javax.management.openmbean.CompositeData;
 import org.netbeans.lib.profiler.common.ProfilingSettingsPresets;
-import org.netbeans.lib.profiler.common.ProfilingSettingsPresets;
+import org.netbeans.lib.profiler.results.cpu.StackTraceSnapshotBuilder;
 
 
 public class LoadedSnapshot {
@@ -193,19 +202,49 @@ public class LoadedSnapshot {
      *
      * @param dis Stream to read from, typically data from file.
      * @return The loaded snapshot or null if failed to load (has already been reported to the user)
-     * @throws IOException If unexpected error occured while loading (should be reported to the user)
+     * @throws IOException If unexpected error occurred while loading (should be reported to the user)
      */
     public static LoadedSnapshot loadSnapshot(DataInputStream dis)
                                        throws IOException {
-        LoadedSnapshot ls = new LoadedSnapshot();
+        dis.mark(100);
+        try {
+            LoadedSnapshot ls = new LoadedSnapshot();
 
-        if (ls.load(dis)) {
-            return ls;
-        } else {
-            return null;
+            if (ls.load(dis)) {
+                return ls;
+            } else {
+                return null;
+            }
+        } catch (IOException ex) {
+            if (INVALID_SNAPSHOT_FILE_MSG.equals(ex.getMessage())) {
+                dis.reset();
+                return loadSnapshotFromStackTraces(dis);
+            }
+            throw ex;
         }
     }
 
+    private static LoadedSnapshot loadSnapshotFromStackTraces(DataInputStream dis) throws IOException {
+        SamplesInputStream is = new SamplesInputStream(dis);
+        StackTraceSnapshotBuilder builder = new StackTraceSnapshotBuilder();
+        ThreadsSample sample = is.readSample();
+        long startTime = sample.getTime();
+
+        for ( ;sample != null; sample = is.readSample()) {
+            builder.addStacktrace(sample.getTinfos(),sample.getTime());
+            
+        }
+        is.close();
+        is = null;
+        CPUResultsSnapshot snapshot;
+        try {
+            snapshot = builder.createSnapshot(startTime);
+        } catch (NoDataAvailableException ex) {
+            throw new IOException(ex);
+        }
+        return new LoadedSnapshot(snapshot, ProfilingSettingsPresets.createCPUPreset(), null);
+    }
+
     static void writeToStream(CPUResultsSnapshot snapshot, DataOutputStream dos) throws IOException {
         LoadedSnapshot loadedSnapshot = new LoadedSnapshot(snapshot,
                 ProfilingSettingsPresets.createCPUPreset(), null);
@@ -466,6 +505,94 @@ public class LoadedSnapshot {
 
         return true;
     }
+
+    static class SamplesInputStream {
+        static final String ID = "NPSS"; // NetBeans Profiler samples stream, it must match org.netbeans.core.ui.sampler.SamplesOutputStream.ID
+
+        int version;
+        ObjectInputStream in;
+        Map<Long,ThreadInfo> threads;
+        
+        SamplesInputStream(File file) throws IOException {
+            this(new FileInputStream(file));
+        }
+
+        SamplesInputStream(InputStream is) throws IOException {
+            readHeader(is);
+            in = new ObjectInputStream(new GZIPInputStream(is));
+            threads = new HashMap(128);
+        }
+
+        ThreadsSample readSample() throws IOException {
+            long time;
+            ThreadInfo infos[];
+            int sameThreads;
+            Map<Long,ThreadInfo> newThreads;
+            
+            try {
+                time = in.readLong();
+            } catch (EOFException ex) {
+                return null;
+            }
+            newThreads = new HashMap(threads.size());
+            sameThreads = in.readInt();
+            for (int i=0;i<sameThreads;i++) {
+                Long tid = Long.valueOf(in.readLong());
+                ThreadInfo oldThread = threads.get(tid);
+                assert oldThread != null;
+                newThreads.put(tid,oldThread);
+            }
+            infos = new ThreadInfo[in.readInt()];
+            for (int i = 0 ; i < infos.length; i++) {
+                CompositeData infoData;
+                ThreadInfo thread;
+                
+                try {
+                    infoData = (CompositeData) in.readObject();
+                } catch (ClassNotFoundException ex) {
+                    throw new RuntimeException(ex);
+                }
+                thread = ThreadInfo.from(infoData);
+                newThreads.put(Long.valueOf(thread.getThreadId()),thread);
+            }
+            threads = newThreads;
+            return new ThreadsSample(time,threads.values());
+        }
+
+        void close() throws IOException {
+            in.close();
+        }
+
+        private void readHeader(InputStream is) throws IOException {
+            String id;
+            byte[] idarr = new byte[ID.length()];
+
+            is.read(idarr);
+            id = new String(idarr);
+            if (!ID.equals(id)) {
+                new IOException("Invalid header "+id); // NOI18N
+            }
+            version = is.read();
+        }
+    }
+
+    static final class ThreadsSample {
+        private final long time;
+        private final ThreadInfo[] tinfos;
+
+        ThreadsSample(long t, Collection<ThreadInfo> tis) {
+            time = t;
+            tinfos = tis.toArray(new ThreadInfo[tis.size()]);
+        }
+
+        long getTime() {
+            return time;
+        }
+
+        ThreadInfo[] getTinfos() {
+            return tinfos;
+        }
+    }
 }
 /* Code to do persist into a ZIP file
    public void save (ZipOutputStream zos) throws IOException {
